@@ -34,18 +34,16 @@
 #define CHANNEL_ID_X11 2
 #define CHANNEL_ID_AGENT 3
 #define CHANNEL_ID_TCPDIRECT 4
+#define CHANNEL_ID_TCPFORWARDED 5
 
-#define SSH_OPEN_ADMINISTRATIVELY_PROHIBITED    1
-#define SSH_OPEN_CONNECT_FAILED                 2
-#define SSH_OPEN_UNKNOWN_CHANNEL_TYPE           3
-#define SSH_OPEN_RESOURCE_SHORTAGE              4
+#define MAX_CHANNELS 60 /* simple mem restriction, includes each tcp/x11
+							connection, so can't be _too_ small */
 
-#define MAX_CHANNELS 400 /* arbitrary, includes each tcp/x11 connection */
 #define CHAN_EXTEND_SIZE 3 /* how many extra slots to add when we need more */
 
 #define RECV_MAXWINDOW 6000 /* tweak */
 #define RECV_MAXPACKET 1400 /* tweak */
-#define RECV_MINWINDOW 10000 /* when we get below this, we send a windowadjust*/
+#define RECV_MINWINDOW 19000 /* when we get below this, we send a windowadjust */
 
 /* a simpler way to define that we need code for listeners */
 #if !defined(DISABLE_X11FWD) || !defined(DISABLE_AUTHFWD) || \
@@ -69,10 +67,10 @@ struct Channel {
 				  a 'session' without a pty will use it */
 	buffer *writebuf; /* data for the program */
 
-	int sentclosed;
-	/* whether we've reached the end of reading/writing to/from/err for a pipe
-	 * or program */
-	int transeof, recveof, erreof; 
+	int sentclosed, recvclosed;
+
+	/* this is set when we receive/send a channel eof packet */
+	int recveof, senteof;
 
 	int initconn; /* used for TCP forwarding, whether the channel has been
 					 fully initialised */
@@ -96,7 +94,8 @@ void recv_msg_channel_close();
 void recv_msg_channel_eof();
 
 #ifdef USE_LISTENERS
-int send_msg_channel_open_init(int fd, const char * typestring);
+int send_msg_channel_open_init(int fd, unsigned char type,
+		const char * typestring);
 void recv_msg_channel_open_confirmation();
 void recv_msg_channel_open_failure();
 #endif
