@@ -15,8 +15,7 @@
 #include <tommath.h>
 
 /* OR two ints together */
-int
-mp_or (mp_int * a, mp_int * b, mp_int * c)
+int mp_or (mp_int * a, mp_int * b, mp_int * c)
 {
   int     res, ix, px;
   mp_int  t, *x;
