@@ -210,7 +210,6 @@ static void session_init(int sock, runopts *opts, int childpipe,
 
 	ses.remoteaddr = remoteaddr;
 
-	ses.addrstring = getaddrstring(remoteaddr);
 	ses.hostname = getaddrhostname(remoteaddr);
 
 	ses.sock = sock;
@@ -240,6 +239,7 @@ static void session_init(int sock, runopts *opts, int childpipe,
 
 	ses.expecting = SSH_MSG_KEXINIT;
 	ses.dataallowed = 0; /* don't send data yet, we'll wait until after kex */
+	ses.ignorenext = 0;
 
 	/* set all the algos to none */
 	ses.keys = (struct key_context*)m_malloc(sizeof(struct key_context));
@@ -277,7 +277,6 @@ static void session_identification() {
 	/* max length of 255 chars */
 	char linebuf[256];
 	int len = 0;
-	int i;
 	char done = 0;
 
 	/* write our version string, this blocks */
@@ -286,23 +285,14 @@ static void session_identification() {
 		dropbear_exit("Error writing ident string");
 	}
 
-	/* Now read the client version string, there are allowed to be other lines
-	 * before the "SSH-*" line. We allow a max of 9 lines before it, just for
-	 * sanity */
-	for (i = 0; i < 10; i++) {
-		len = ident_readln(ses.sock, linebuf, 256);
-		if (len < 0) {
-			break;
-		}
-		if (len >= 4 && memcmp(linebuf, "SSH-", 4) == 0) {
-			/* start of line matches */
-			done = 1;
-			break;
-		}
+	len = ident_readln(ses.sock, linebuf, 256);
+	if (len >= 4 && memcmp(linebuf, "SSH-", 4) == 0) {
+		/* start of line matches */
+		done = 1;
 	}
 
 	if (!done) {
-		dropbear_exit("Failed to get remote ident");
+		dropbear_exit("Failed to get client version");
 	} else {
 		/* linebuf is already null terminated */
 		ses.remoteident = m_malloc(len);
